

/** 
 * Applet to test JanneToolbar class, using inline xpm data.
 *
 * This applet uses a sub-class of JanneButton to create buttons
 * that handles URL's.
 *
 */
import java.awt.*;
import java.awt.image.*;
import java.net.URL;
import java.net.MalformedURLException;
import java.applet.Applet;

/**
 * URLButton is a sub-class of JanneButton to handle an URL connected
 * with the button.
 */
class URLButton extends JanneButton {
   Applet applet;		// applet used
   String urlString;		// URL string
   String infoString;		// Info. string

   /**
    * Construct button
    */
   URLButton(Applet applet, Image image, String label,
	     String url, String info) {
      super(image, label, 2, 2, false, true);
      this.applet = applet;
      urlString = url;
      infoString = info;
   }

   /**
    * Get URL
    */
   public URL getUrl() {
      URL url = null;
      // first, try to get url in context of current document
      try {
	 url = new URL(applet.getDocumentBase(), urlString);
      }
      catch (MalformedURLException e) {
	 applet.showStatus(e.getMessage());
	 url = null;
      }
      if (url == null) {
	 // next, try to get url directly 
	 try {
	    url = new URL(urlString);
	 }
	 catch (MalformedURLException e) {
	    applet.showStatus(e.getMessage());
	    url = null;
	 }
      }
      return url;
   }
   
   /**
    * Handle mouse event to set message
    */
   public boolean mouseEnter(Event evt, int x, int y) {
      applet.showStatus(infoString);
      return super.mouseEnter(evt, x, y);
   }
   
   public boolean mouseMove(Event evt, int x, int y) {
      applet.showStatus(infoString);
      return super.mouseMove(evt, x, y);
   }
   
   public boolean mouseExit(Event evt, int x, int y) {
      applet.showStatus("");
      return super.mouseExit(evt, x, y);
   }
}

public class JanneToolbarTest2 extends Applet {
   JanneToolbar toolbar;	// the toolbar
   String target;		// Netscape target window
   
   public void init() {
      // Set background
      setBackground(new Color(0xEED5B7));

      target = getParameter("target");

      // Create the (hardcoded, in-line xpm) images
      Image info = createImage(new XImageSource(infoPixmap));
      Image tools = createImage(new XImageSource(toolsPixmap));
      Image java = createImage(new XImageSource(javaPixmap));
      Image hotlist = createImage(new XImageSource(hotListPixmap));
      Image mail = createImage(new XImageSource(mailPixmap));

      // Create (vertical) toolbar panel and add buttons
      toolbar = new JanneToolbar(false, 2, true);
      toolbar.addButton(
	 new URLButton(this, java, "JanneToolbar",
		       "JanneToolbarMain.html",
		       "Go to: JanneToolbar Home Page"));
      toolbar.addButton(
	 new URLButton(this, info, "About Me...",
		       "http://www.algonet.se/~jannea/torpa.html",
		       "Go to: http://www.algonet.se/~jannea/torpa.html"),
	 4);
      toolbar.addButton(
	 new URLButton(this, java, "Java Applets",
		       "http://www.algonet.se/~jannea/applets.html",
		       "Go to: http://www.algonet.se/~jannea/applets.html"),
	 4);
      toolbar.addButton(
	 new URLButton(this, java, "Java Classes",
		       "http://www.algonet.se/~jannea/classes.html",
		       "Go to: http://www.algonet.se/~jannea/classes.html"));
      toolbar.addButton(
	 new URLButton(this, hotlist, "Java Links",
		       "http://www.algonet.se/~jannea/javalinks.html",
		       "Go to: http://www.algonet.se/~jannea/javalinks.html"));
      toolbar.addButton(
	 new URLButton(this, tools, "Applications",
		       "http://www.algonet.se/~jannea/apps.html",
		       "Go to: http://www.algonet.se/~jannea/apps.html"),
	 4);
      toolbar.addButton(
	 new URLButton(this, mail, "E-mail",
		       "mailto:janne@torpa.se",
		       "Send mail to: janne@torpa.se"),
	 4);
      add(toolbar);
   }

   /**
    * Got to URL when button selected
    */
   public boolean action(Event evt, Object arg) {
      if (evt.target instanceof URLButton) {
	 URLButton butt = (URLButton) evt.target;
	 URL url = butt.getUrl();
	 if (url != null) {
	    if (target != null)
	       getAppletContext().showDocument(url, target);
	    else
	       getAppletContext().showDocument(url);
	 }
	 setCurrent(butt);
      }
      return true;
   }

   /**
    * Mark button as current
    */
   void setCurrent(URLButton button) {
      // reset buttons
      int nButtons = toolbar.countComponents();
      for (int i=0; i<nButtons; i++) {
	 Component c = toolbar.getComponent(i);
	 if (c.getForeground() != getForeground()) {
	    c.setForeground(getForeground());
	    c.repaint();
	 }
      }
      // mark as current (using red foreground)
      button.setForeground(Color.red);
   }

   /**
    * Finally, the inline xpm data...
    */
   private static String[] infoPixmap = {
      /* width height ncolors cpp [x_hot y_hot] */
      "48 48 11 1 0 0",
      /* colors */
      " 	s none	m none	c none",
      ".	s iconGray1	m white	c #dededededede",
      "X	s iconColor2	m white	c white",
      "o	s iconGray6	m black	c #636363636363",
      "O	s iconGray5	m black	c #737373737373",
      "+	s iconGray2	m white	c #bdbdbdbdbdbd",
      "@	s iconColor5	m black	c blue",
      "#	s iconGray3	m white	c #adadadadadad",
      "$	s iconGray7	m black	c #424242424242",
      "%	s iconGray4	m white	c #949494949494",
      "&	s iconGray8	m black	c #212121212121",
      /* pixels */
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                   ...XXXX.ooO                  ",
      "                 .+.@#@#@#@#@#oo                ",
      "                X++@#@@@@@#@#@#oo               ",
      "             XXX@#@#@@XXX@@#@#@#ooo             ",
      "             X#@#@#@@XXXXX@@#@#@#$o             ",
      "           XX#@#@#@@XXXXXXX@@#@#@#oo            ",
      "          XX#@#@#@#@XXXXXXX@@@#@#@#oo           ",
      "          X#@#@#@#@@XXXXXXX@@#@#@#@#oO          ",
      "        ..X@#@#@#@#@XXXXXXX@@@#@#@#@#$O         ",
      "        XX@#@#@#@#@#@XXXXX@@@#@#@#@#@%$         ",
      "        X@#@#@#@#@#@#@XXX@@@#@#@#@#@#@$         ",
      "       .X#@#@#@#@#@@@@@@@@@#@#@#@#@#@#$O        ",
      "       X.@#@#@#@#@#@XXXXX@@@#@#@#@#@#@OO        ",
      "       X@#@#@#@#@#@@XXXXX@@@@#@#@#@#@+@O        ",
      "       X#@#@#@#@@@@XXXXXXX@@#@#@#@#@#@O$        ",
      "       X@#@#@#@#@XXXXXXXXX@@@#@#@#@#@+@$        ",
      "       X#@#@#@#@@XXXXXXXXX@@#@#@#@#@#@O$        ",
      "       X@#@#@#@#@@@@XXXXXX@@@#@#@#@#@#@$        ",
      "       X#@#@#@#@#@#@XXXXXX@@#@#@#@#@#@O$        ",
      "       X@#@#@#@#@#@@XXXXXX@@@#@#@#@#@+@$        ",
      "       X#@#@#@#@#@#@XXXXXX@@#@#@#@#@#@O$        ",
      "       ..#@#@#@#@#@@XXXXXX@@@#@#@#@#@%@$        ",
      "       O.@#@#@#@#@#@XXXXXX@@@@@@#@#@#@&o        ",
      "        .#@#@#@#@#@@XXXXXXXXX@@@@#@#@O$         ",
      "        O.#@#@#@#@#@XXXXXXXX@@@@#@#@#$$         ",
      "         ..#@#@#@#@@XXXXXXXX@@@#@#@#$o          ",
      "         O.@#@#@#@#@@@XXXX@@@@#@#@#@$o          ",
      "           .@#@#@#@#@@@@@@@@@#@#@#$$o           ",
      "          O%.@#@#@#@#@#@#@#@#@#@#@$o            ",
      "           O.+@#@#@#@#@#@#@#@#@#$oo             ",
      "             ##@#@#@#@#@#@#@#@#$oo              ",
      "              ##@#@#@#@#@#@#$ooo                ",
      "                 ##$$$$$$$$$$o                  ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                "
   };
   private static String[] toolsPixmap = {
      /* width height ncolors cpp [x_hot y_hot] */
      "48 48 15 1 0 0",
      /* colors */
      " 	s none	m none	c none",
      ".	s iconGray5	m black	c #737373737373",
      "X	s iconGray4	m white	c #949494949494",
      "o	s iconGray2	m white	c #bdbdbdbdbdbd",
      "O	s iconColor2	m white	c white",
      "+	s iconGray1	m white	c #dededededede",
      "@	s iconColor6	m white	c yellow",
      "#	s iconGray3	m white	c #adadadadadad",
      "$	s iconGray6	m black	c #636363636363",
      "%	s iconGray7	m black	c #424242424242",
      "&	s iconGray8	m black	c #212121212121",
      "*	s iconColor1	m black	c black",
      "=	s iconColor5	m black	c blue",
      "-	s iconColor7	m white	c cyan",
      ";	s iconColor3	m black	c red",
      /* pixels */
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                           .X.                  ",
      "                          .XXo.                 ",
      "       O+                .@@X#o.                ",
      "      O+oO             ..X$@@X#o.               ",
      "     O+ooo+            ..+X$@OX#o.              ",
      "    $.ooooo+          $%&$oX$@@X#o.             ",
      "    .$$oooooo         ..%&$oX$@@Xoo.            ",
      "     $%$ooooo$        ...%$$oX$@OXoo.           ",
      "      .%$oooXO        ....%&$oX$@@Xoo.          ",
      "       ..$&XXXO        ....%&$oX$@@Xoo.         ",
      "        $$.&XXXO        ....%$$oX$@OXoo.        ",
      "         ...&XXXO        .$o+%%$oX$@@Xoo.       ",
      "          ...&XXXO       $++o%%&$oX$@@XoX.      ",
      "           ...&XXXO     .o++o%%%$$oX$@OXX&.     ",
      "            ...&XXXO   $o+oo%...%%$oX$@X*..     ",
      "             ...&XXX==-++o.%.....%%$oXX*...     ",
      "              ...&XX=-.++o%.......%$$+*....     ",
      "               ...&=-.=$==&&.......%&*.....     ",
      "                .==-.-.==&%%.    .........      ",
      "                 =-.=#===&%%.     .......       ",
      "                =-.-$==&&%$$       .....        ",
      "               =-.=.==&%%&$$$&                  ",
      "              =-.-#===&%%&$$@o&                 ",
      "             =-.=.==&%%&&.;@@++&                ",
      "            =-.-.==&%.$&&;@@@@@+&               ",
      "           =-.=#===%..$&&;@@;@@+o&              ",
      "          =-.-.==&%...  &%;;@;@@++&             ",
      "         =-.=.==&%.... ..&%%;@@@@@+&            ",
      "        =-.-#===%..... ...%%;@@;@@+o&           ",
      "       =-.=.==&%.....   ...&%;;@;@@++&          ",
      "      ==.-.==&%.....     ...&%%;@@@@@&$         ",
      "     ====#===%.....       ...%%;@@;@@&$         ",
      "     ======&%.....         ...&%;;@;;&$         ",
      "     &&&&&&%.....           ...&%;@&&..         ",
      "      &&&&&.....              ..%%&&&..         ",
      "       %.......                .......          ",
      "        ......                  .....           ",
      "         ....                                   ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                "
   };
   
   private static String[] javaPixmap = {
      /* width height ncolors cpp [x_hot y_hot] */
      "48 48 81 1 0 0",
      /* colors */
      " 	s none	m none	c none",
      ".	c #D4D44F4F5454",
      "X	c #D5D515151717",
      "o	c #C8C898989999",
      "O	c #C8C8AFAFA1A1",
      "+	c #BDBDB3B3B2B2",
      "@	c #C0C08B8B7B7B",
      "#	c #D4D43B3B3535",
      "$	c #D1D169696767",
      "%	c #D6D6A3A38787",
      "&	c #CDCDB1B1B2B2",
      "*	c #B8B81D1D2222",
      "=	c #BDBDB5B5BDBD",
      "-	c #C6C6C1C1BBBB",
      ";	c #C6C6BDBDC6C6",
      ":	c #BFBFD0D0CECE",
      "?	c #C0C0C0C0C0C0",
      ">	s iconGray2	m white	c #bdbdbdbdbdbd",
      ",	c #BDBDC2C2C6C6",
      "<	c #CECECECECDCD",
      "1	c #B6B68D8D8888",
      "2	c #D1D1C6C6C6C6",
      "3	c #B5B5ADADADAD",
      "4	c #9E9E61616767",
      "5	c #B5B5ADADB5B5",
      "6	c #ADADA5A5ADAD",
      "7	c #B5B5B4B4BDBD",
      "8	c #BDBDAFAFD6D6",
      "9	c #7E7E7F7F9E9E",
      "0	c #86868989B3B3",
      "q	c #39392C2C6767",
      "w	c #6D6D57579292",
      "e	c #84846F6FABAB",
      "r	c #AAAAA5A5B8B8",
      "t	c #8C8C83839B9B",
      "y	c #6F6F69698E8E",
      "u	c #636356569494",
      "i	s iconGray3	m white	c #adadadadadad",
      "p	c #96968787B4B4",
      "a	c #CBCBBDBDDFDF",
      "s	c #424231318484",
      "d	c #3A3A2A2A4D4D",
      "f	c #484840406969",
      "g	c #23231D1D5858",
      "h	c #585854549090",
      "j	c #9B9B9898B1B1",
      "k	c #555555558484",
      "l	c #9D9D5A5A3131",
      "z	c #A5A59999A4A4",
      "x	c #5A5A4A4A7B7B",
      "c	c #636359598484",
      "v	c #B0B09292D6D6",
      "b	c #ADADADADB8B8",
      "n	c #0E0E0C0C1C1C",
      "m	c #66665C5C7373",
      "M	c #3B3B24243131",
      "N	c #222217173D3D",
      "B	c #5A5A42427B7B",
      "V	c #D6D6D4D4E6E6",
      "C	c #94948B8BA0A0",
      "Z	c #A5A5A5A5ADAD",
      "A	c #9E9E8080CACA",
      "S	c #7B7B6B6B9797",
      "D	c #71716161A3A3",
      "F	c #9C9C9C9CA5A5",
      "G	c #66664D4D4343",
      "H	c #272715151818",
      "J	c #A6A69A9AB3B3",
      "K	c #94949494A4A4",
      "L	c #5A5A4A4A8484",
      "P	c #B5B5B5B5B5B5",
      "I	c #5A5A42428888",
      "U	c #7B7B6969ACAC",
      "Y	c #A1A1B3B3CFCF",
      "T	c #9C9C9494A5A5",
      "R	c #63634A4A8484",
      "E	c #4C4C4E4E7B7B",
      "W	c #848473738B8B",
      "Q	c #CECED0D0DDDD",
      "!	c #5A5A56567B7B",
      "~	s iconGray6	m black	c #636363636363",
      /* pixels */
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                      .XXXX.o                   ",
      "                 O+ @#$o%&@$#O                  ",
      "               ooO o#o     o*.&                 ",
      "              $#@= *O       @.O                 ",
      "             .#o  &$        &$o                 ",
      "            ..o   #+$o      -.$                 ",
      "           $#$;  O# $$O     :..                 ",
      "          o#Xo   $#O$#$O    O$?                 ",
      "         -$.Xo   .#$$*#o>  @*, $.               ",
      "         &#@X$<  .$X##.@o Oo? #Xo               ",
      "         O#O##&  @$Xo$X$@ = %##1                ",
      "         @#O1X$2 @##+$X@@&+o#X$                 ",
      "         o#o .X$2.XoXX@&#o$.=.@                 ",
      "         OX@  $XXXXXXo #o%$  .@                 ",
      "         >#X   OO#XX$o@#&#$  $.3                ",
      "          OX.O   O#. .#oo#&  O$$1               ",
      "           oX#1> +*.O.$ .$    344               ",
      "            oXX*X***.$o .o     56               ",
      "                 7 ***@ @X$>      78>           ",
      "              699  *.#.  #$   , 80qwe8          ",
      "            rtyu   *i,$* o*$ p;asdfgghr         ",
      "          >jqgk>?<al=?O*zo4qxc,v9  zfgv         ",
      "           >bqnqc9qsqmMNBfnd ?VpC0h6ZnA         ",
      "             bSDFG*xcM*GSH4  8qJ7jDt Ne         ",
      "              =K1X#>1X#51#  <Lq   vy qj         ",
      "             ZfcG*jZXX?;X? gqur   9PdLr         ",
      "             CgqwhsBhksuILIUr    YitqJ          ",
      "              zLyyj8Jjprr6,8T,  2?qne           ",
      "              ZgRyJb;>,>>JUhS= >7vEJ            ",
      "               gqqsfsshDcIhuC  ,ey6             ",
      "           >fW  rDgCJirpIIh=   8=PTS            ",
      "        7KyqI7  ,8egNNNgsy7>   8p;JeDT          ",
      "       >yK8qD    <Qp0ee0J=    <uF 88qp          ",
      "       =fj,ju07;             rL0  8jsp          ",
      "        =!r=JDuD0jb> >7b6TC0wwt   JsR           ",
      "         >~wbJpeSDusfBkRcy9C7  7rtEe8           ",
      "          >Z9cetSSSSDwy990Cp0eUeUUr5            ",
      "             6zCSRcRLEsfsBhcy9tCF5              ",
      "               =7PiZzzzJ6b===P7P=               ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                "
   };
   private static String[] hotListPixmap = {
      /* width height ncolors cpp [x_hot y_hot] */
      "48 48 6 1 0 0",
      /* colors */
      " 	s none	m none	c none",
      ".	s iconColor3	m black	c red",
      "X	s iconColor6	m white	c yellow",
      "o	s iconColor1	m black	c black",
      "O	c #FFFFFAFACDCD",
      "+	c #D2D2B4B48C8C",
      /* pixels */
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "            .    .       ..      .              ",
      "            .    ..     .X.     ..              ",
      "           ..    ..    .XX.     .X.             ",
      "           .X.   .X.  .XX.     .XX.             ",
      "           .X.   .X. .XXX.     .XX.             ",
      "          ..X.   .X. .XX.     .XX.              ",
      "           .XX. .XX. .XX.. ....XX.              ",
      "           .XX. .XX.  .XX.  .X..XX.             ",
      "            . X.XX..   .XX.  .X..X..            ",
      "            .XX.XX.    .XX.   .X.XX.            ",
      "           .XX .XX.    .XX..  .X..XX.           ",
      "           .XX..XX.    .X.X.  .XX.XX.           ",
      "          .XX.X.XX.   .XXX.  .XXX.XX..          ",
      "          .X.X .XXX. ..XXX.. .X.X.XXXX.         ",
      "          .oX.o.X.X.oo.XXX.oo.X.XX.X.X.         ",
      "          oXX.O.XXOOOO.XX.OOO.XXX.XX++o.        ",
      "          oXXooXXoooooooooooOO.X.X+++OOo        ",
      "          oXOOOOOOOOOOOOOOOOOO.Xo+++OOOo        ",
      "           oOooOOoooooOOOOOOOOOOo+++OOOo        ",
      "           oOOOOOOOOOOOOOOOOOOOOo+++OOOo        ",
      "            oOooOOoooooooooOOOOOOo+++Oo         ",
      "            oOOOOOOOOOOOOOOOOOOOOooooo          ",
      "             oOOooOOooooooooooooOOo             ",
      "              oOOOOOOOOOOOOOOOOOOOOo            ",
      "              oOOooOOoooooOOOOOOOOOo            ",
      "               oOOOOOOOOOOOOOOOOOOOOo           ",
      "               oOooOOoooooooooOOOOOOo           ",
      "               oOOOOOOOOOOOOOOOOOOOOOo          ",
      "             oooooooooooooooooooooooOOo         ",
      "            oOOOOOOOOOOOOOOOOOOOOo+++Oo         ",
      "           oOOOOOOOOOOOOOOOOOOOOo+++OOOo        ",
      "           oOOOOOOOOOOOOOOOOOOOOo+++OOOo        ",
      "           oOOOOOOOOOOOOOOOOOOOOo+++OOOo        ",
      "           oOOOOOOOOOOOOOOOOOOOOo+++OOOo        ",
      "            oOOOOOOOOOOOOOOOOOOOOo+++Oo         ",
      "             ooooooooooooooooooooooooo          ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                "
   };
   private static String[] mailPixmap = {
      /* width height ncolors cpp [x_hot y_hot] */
      "48 48 8 1 0 0",
      /* colors */
      " 	s none	m none	c none",
      ".	s iconColor2	m white	c white",
      "X	s iconGray1	m white	c #dededededede",
      "o	s iconGray5	m black	c #737373737373",
      "O	s iconColor3	m black	c red",
      "+	s iconGray2	m white	c #bdbdbdbdbdbd",
      "@	s iconGray4	m white	c #949494949494",
      "#	s iconColor4	m white	c green",
      /* pixels */
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "   ..........................................   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXOOXXXOOXX+..+Xo   ",
      "   .XX@@@XX@@@XXXXXXXXXXXXXXXXXXOOOXXOX.#+.Xo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXOOXXOXXOX++#+Xo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXOOXOOXX.#+.Xo   ",
      "   .XX@@X@@@@XXXXXXXXXXXXXXXXXXXXXXXXXX+..+Xo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXX@@@X@@@@@XX@@@X@@XXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXX@@@@XX@@@XX@@@@XXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXX@@@@X@@X@@@@@XXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo   ",
      "   .ooooooooooooooooooooooooooooooooooooooooo   ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                ",
      "                                                "
   };
   
}

